@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,13 +7,14 @@
 #ifndef TEST_AUTOCORRECTION_GUI_H
 #define TEST_AUTOCORRECTION_GUI_H
 
-#include <QWidget>
 #include <KSharedConfig>
 #include <QDialog>
+#include <QWidget>
 
 #include <QTextEdit>
 
-namespace PimCommon {
+namespace PimCommon
+{
 class AutoCorrection;
 class AutoCorrectionWidget;
 class LineEditWithAutoCorrection;
