@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,7 +11,8 @@
 
 #include <QWidget>
 class KToggleAction;
-namespace PimCommon {
+namespace PimCommon
+{
 /**
  * @brief The CustomToolsViewInterface class
  * @author Laurent Montel <montel@kde.org>
