@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,9 +7,10 @@
 #ifndef AbstractGENERICPLUGIN_H
 #define AbstractGENERICPLUGIN_H
 
-#include <QObject>
 #include "pimcommon_export.h"
-namespace PimCommon {
+#include <QObject>
+namespace PimCommon
+{
 class AbstractGenericPluginInterface;
 /**
  * @brief The AbstractGenericPlugin class
@@ -20,7 +21,7 @@ class PIMCOMMON_EXPORT AbstractGenericPlugin : public QObject
     Q_OBJECT
 public:
     explicit AbstractGenericPlugin(QObject *parent = nullptr);
-    ~AbstractGenericPlugin();
+    ~AbstractGenericPlugin() override;
 
     virtual PimCommon::AbstractGenericPluginInterface *createInterface(QObject *parent = nullptr) = 0;
     Q_REQUIRED_RESULT virtual bool hasPopupMenuSupport() const;
