@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,19 +7,21 @@
 #ifndef LOGACTIVITIESWIDGET_H
 #define LOGACTIVITIESWIDGET_H
 
-#include <QWidget>
 #include "pimcommon_private_export.h"
-namespace KPIMTextEdit {
+#include <QWidget>
+namespace KPIMTextEdit
+{
 class PlainTextEditorWidget;
 class PlainTextEditor;
 }
-namespace PimCommon {
+namespace PimCommon
+{
 class PIMCOMMON_TESTS_EXPORT LogActivitiesWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit LogActivitiesWidget(QWidget *parent = nullptr);
-    ~LogActivitiesWidget();
+    ~LogActivitiesWidget() override;
     void setLog(const QString &str);
     Q_REQUIRED_RESULT QString log() const;
     void clear();
