@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef MIGRATEFILEINFO_H
@@ -23,7 +11,8 @@
 #include <QStringList>
 
 #include "pimcommon_export.h"
-namespace PimCommon {
+namespace PimCommon
+{
 /**
  * @brief The MigrateFileInfo class
  * @author Laurent Montel <montel@kde.org>
@@ -54,8 +43,8 @@ private:
     QStringList mFilePattern;
     QString mType;
     QString mPath;
-    int mVersion;
-    bool mFolder;
+    int mVersion = -1;
+    bool mFolder = false;
 };
 }
 
