@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,16 +10,18 @@
 #include <QDialog>
 
 class QLineEdit;
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class PlainTextEditorWidget;
 }
-namespace PimCommon {
+namespace PimCommon
+{
 class TemplateEditDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit TemplateEditDialog(QWidget *parent = nullptr, bool defaultTemplate = false);
-    ~TemplateEditDialog();
+    ~TemplateEditDialog() override;
 
     void setTemplateName(const QString &name);
     Q_REQUIRED_RESULT QString templateName() const;
