@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,7 +9,8 @@
 
 #include <QDialog>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class PlainTextEditorWidget;
 }
 class TranslatorDebugDialog : public QDialog
@@ -17,7 +18,7 @@ class TranslatorDebugDialog : public QDialog
     Q_OBJECT
 public:
     explicit TranslatorDebugDialog(QWidget *parent = nullptr);
-    ~TranslatorDebugDialog();
+    ~TranslatorDebugDialog() override;
 
     void setDebug(const QString &debugStr);
 
