@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #ifndef PURPOSEMENUWIDGETTEST_H
 #define PURPOSEMENUWIDGETTEST_H
 
-#include <QObject>
 #include "widgets/purposemenuwidget.h"
+#include <QObject>
 class TestMenu : public PimCommon::PurposeMenuWidget
 {
     Q_OBJECT
@@ -29,7 +29,7 @@ class PurposeMenuWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit PurposeMenuWidgetTest(QObject *parent = nullptr);
-    ~PurposeMenuWidgetTest() = default;
+    ~PurposeMenuWidgetTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValues();
 };
