@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,7 +16,7 @@ using namespace PimCommon;
 LineEditWithCompleterNg::LineEditWithCompleterNg(QWidget *parent)
     : QLineEdit(parent)
 {
-    auto *completer = new QCompleter(this);
+    auto completer = new QCompleter(this);
     mCompleterListModel = new QStringListModel(this);
     completer->setModel(mCompleterListModel);
     setCompleter(completer);
@@ -41,7 +41,10 @@ void LineEditWithCompleterNg::contextMenuEvent(QContextMenuEvent *e)
     QMenu *popup = QLineEdit::createStandardContextMenu();
     if (popup) {
         popup->addSeparator();
-        popup->addAction(QIcon::fromTheme(QStringLiteral("edit-clear-locationbar-rtl")), i18n("Clear History"), this, &LineEditWithCompleterNg::slotClearHistory);
+        popup->addAction(QIcon::fromTheme(QStringLiteral("edit-clear-locationbar-rtl")),
+                         i18n("Clear History"),
+                         this,
+                         &LineEditWithCompleterNg::slotClearHistory);
         popup->exec(e->globalPos());
         delete popup;
     }
