@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,14 +7,16 @@
 #ifndef PURPOSEMENUWIDGET_H
 #define PURPOSEMENUWIDGET_H
 
-#include <QObject>
 #include "pimcommon_export.h"
-namespace Purpose {
+#include <QObject>
+namespace Purpose
+{
 class Menu;
 }
 class QMenu;
 class QTemporaryFile;
-namespace PimCommon {
+namespace PimCommon
+{
 /**
  * @brief The PurposeMenuWidget class
  * @author Laurent Montel <montel@kde.org>
@@ -28,6 +30,7 @@ public:
 
     virtual QByteArray text() = 0;
     QMenu *menu() const;
+
 private:
     void slotInitializeShareMenu();
     void slotShareActionFinished(const QJsonObject &output, int error, const QString &message);
