@@ -15,13 +15,13 @@
 #include <KLocalizedString>
 
 #include <QButtonGroup>
+#include <QDialogButtonBox>
 #include <QGridLayout>
 #include <QGroupBox>
 #include <QLabel>
 #include <QPushButton>
 #include <QRadioButton>
 #include <QVBoxLayout>
-#include <QDialogButtonBox>
 
 using namespace PimCommon;
 
@@ -57,9 +57,7 @@ void AclEntryDialog::Private::slotSelectAddresses()
         return;
     }
 
-    const QString text = !dlg.selectedAddresses().isEmpty()
-                         ? dlg.selectedAddresses().at(0).quotedEmail()
-                         : QString();
+    const QString text = !dlg.selectedAddresses().isEmpty() ? dlg.selectedAddresses().at(0).quotedEmail() : QString();
 
     mUserIdLineEdit->setText(text);
 }
@@ -68,37 +66,36 @@ AclEntryDialog::AclEntryDialog(QWidget *parent)
     : QDialog(parent)
     , d(new Private(this))
 {
-    auto *mainLayout = new QVBoxLayout(this);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto mainLayout = new QVBoxLayout(this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     d->mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     d->mOkButton->setDefault(true);
     d->mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &AclEntryDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &AclEntryDialog::reject);
 
-    QWidget *page = new QWidget(this);
+    auto page = new QWidget(this);
     mainLayout->addWidget(page);
     mainLayout->addWidget(buttonBox);
 
-    auto *layout = new QGridLayout(page);
+    auto layout = new QGridLayout(page);
     layout->setContentsMargins(0, 0, 0, 0);
 
-    QLabel *label = new QLabel(i18n("&User identifier:"), page);
+    auto label = new QLabel(i18n("&User identifier:"), page);
     layout->addWidget(label, 0, 0);
 
     d->mUserIdLineEdit = new PimCommon::AddresseeLineEdit(page);
     layout->addWidget(d->mUserIdLineEdit, 0, 1);
     label->setBuddy(d->mUserIdLineEdit);
-    d->mUserIdLineEdit->setWhatsThis(
-        i18nc("@info:whatsthis",
-              "The User Identifier is the login of the user on the IMAP server. "
-              "This can be a simple user name or the full email address of the user; "
-              "the login for your own account on the server will tell you which one it is."));
+    d->mUserIdLineEdit->setWhatsThis(i18nc("@info:whatsthis",
+                                           "The User Identifier is the login of the user on the IMAP server. "
+                                           "This can be a simple user name or the full email address of the user; "
+                                           "the login for your own account on the server will tell you which one it is."));
 
-    QPushButton *button = new QPushButton(i18nc("select an email address", "Se&lect..."), page);
+    auto button = new QPushButton(i18nc("select an email address", "Se&lect..."), page);
     layout->addWidget(button, 0, 2);
 
-    QGroupBox *groupBox = new QGroupBox(i18n("Permissions"), page);
+    auto groupBox = new QGroupBox(i18n("Permissions"), page);
     d->mButtonLayout = new QVBoxLayout(groupBox);
 
     d->mButtonGroup = new QButtonGroup(groupBox);
@@ -106,8 +103,7 @@ AclEntryDialog::AclEntryDialog(QWidget *parent)
     for (unsigned int i = 0; i < AclUtils::standardPermissionsCount(); ++i) {
         const KIMAP::Acl::Rights permissions = AclUtils::permissionsForIndex(i);
 
-        QRadioButton *radioButton
-            = new QRadioButton(AclUtils::permissionsToUserString(permissions), groupBox);
+        auto radioButton = new QRadioButton(AclUtils::permissionsToUserString(permissions), groupBox);
         d->mButtonLayout->addWidget(radioButton);
         d->mButtonGroup->addButton(radioButton, permissions);
     }
@@ -115,9 +111,7 @@ AclEntryDialog::AclEntryDialog(QWidget *parent)
     d->mButtonLayout->addStretch(1);
     layout->addWidget(groupBox, 1, 0, 1, 3);
 
-    label
-        = new QLabel(
-              i18n("<b>Note: </b>Renaming requires write permissions on the parent folder."), page);
+    label = new QLabel(i18n("<b>Note: </b>Renaming requires write permissions on the parent folder."), page);
     layout->addWidget(label, 2, 0, 1, 3);
     layout->setRowStretch(2, 10);
 
@@ -160,8 +154,7 @@ void AclEntryDialog::setPermissions(KIMAP::Acl::Rights permissions)
     if (button) {
         button->setChecked(true);
     } else {
-        QRadioButton *radioButton
-            = new QRadioButton(AclUtils::permissionsToUserString(permissions));
+        auto radioButton = new QRadioButton(AclUtils::permissionsToUserString(permissions));
 
         d->mButtonLayout->addWidget(radioButton);
         d->mButtonGroup->addButton(radioButton, permissions);
@@ -178,8 +171,7 @@ KIMAP::Acl::Rights AclEntryDialog::permissions() const
         return d->mCustomPermissions;
     }
 
-    return KIMAP::Acl::denormalizedRights(
-        static_cast<KIMAP::Acl::Rights>(d->mButtonGroup->id(button)));
+    return KIMAP::Acl::denormalizedRights(static_cast<KIMAP::Acl::Rights>(d->mButtonGroup->id(button)));
 }
 
 #include "moc_aclentrydialog_p.cpp"
