@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,14 +9,15 @@
 
 #include <QWidget>
 class QCheckBox;
-namespace PimCommon {
+namespace PimCommon
+{
 class AclManager;
 class CollectionAclWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit CollectionAclWidget(QWidget *parent = nullptr);
-    ~CollectionAclWidget();
+    ~CollectionAclWidget() override;
 
     Q_REQUIRED_RESULT PimCommon::AclManager *aclManager() const;
     Q_REQUIRED_RESULT bool recursive() const;
