@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -11,13 +11,14 @@
 #include <QObject>
 
 #include "pimcommonakonadi_private_export.h"
-namespace PimCommon {
+namespace PimCommon
+{
 class PIMCOMMONAKONADI_TESTS_EXPORT BlackListBalooEmailSearchJob : public QObject
 {
     Q_OBJECT
 public:
     explicit BlackListBalooEmailSearchJob(QObject *parent = nullptr);
-    ~BlackListBalooEmailSearchJob();
+    ~BlackListBalooEmailSearchJob() override;
 
     Q_REQUIRED_RESULT bool start();
 
