@@ -9,7 +9,6 @@
 
 #include "completionordereditor.h"
 #include "completionorderwidget.h"
-#include <KDescendantsProxyModel>
 #include <KLDAP/LdapClient>
 #include <KLDAP/LdapClientSearch>
 
@@ -19,10 +18,10 @@
 
 #include <KConfigGroup>
 #include <KLocalizedString>
-#include <QPushButton>
-#include <QVBoxLayout>
 #include <KSharedConfig>
 #include <QDialogButtonBox>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 using namespace PimCommon;
 
@@ -41,7 +40,7 @@ CompletionOrderEditor::CompletionOrderEditor(KLDAP::LdapClientSearch *ldapSearch
     , d(new PimCommon::CompletionOrderEditorPrivate)
 {
     setWindowTitle(i18nc("@title:window", "Edit Completion Order"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
     d->mCompletionOrderWidget = new CompletionOrderWidget(this);
     d->mCompletionOrderWidget->setObjectName(QStringLiteral("completionorderwidget"));
@@ -52,7 +51,7 @@ CompletionOrderEditor::CompletionOrderEditor(KLDAP::LdapClientSearch *ldapSearch
 
     d->mCompletionOrderWidget->loadCompletionItems();
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
