@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,10 +7,11 @@
 #ifndef ADDRESSESSLINEEDITPLUGINMANAGER_H
 #define ADDRESSESSLINEEDITPLUGINMANAGER_H
 
-#include <QObject>
 #include "pimcommonakonadi_export.h"
+#include <QObject>
 
-namespace PimCommon {
+namespace PimCommon
+{
 class AddressessLineEditAbstractPlugin;
 class AddressessLineEditPluginManagerPrivate;
 /**
@@ -22,7 +23,7 @@ class PIMCOMMONAKONADI_EXPORT AddressessLineEditPluginManager : public QObject
     Q_OBJECT
 public:
     explicit AddressessLineEditPluginManager(QObject *parent = nullptr);
-    ~AddressessLineEditPluginManager();
+    ~AddressessLineEditPluginManager() override;
 
     static AddressessLineEditPluginManager *self();
 
