@@ -1,28 +1,17 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef SELECTMULTICOLLECTIONDIALOG_H
 #define SELECTMULTICOLLECTIONDIALOG_H
 #include "pimcommonakonadi_export.h"
-#include <QDialog>
 #include <Collection>
+#include <QDialog>
 
-namespace PimCommon {
+namespace PimCommon
+{
 class SelectMultiCollectionDialogPrivate;
 /**
  * @brief The SelectMultiCollectionDialog class
@@ -34,7 +23,7 @@ class PIMCOMMONAKONADI_EXPORT SelectMultiCollectionDialog : public QDialog
 public:
     explicit SelectMultiCollectionDialog(const QString &mimetype, const QList<Akonadi::Collection::Id> &selectedCollection, QWidget *parent = nullptr);
     explicit SelectMultiCollectionDialog(const QString &mimetype, QWidget *parent = nullptr);
-    ~SelectMultiCollectionDialog();
+    ~SelectMultiCollectionDialog() override;
 
     Q_REQUIRED_RESULT QVector<Akonadi::Collection> selectedCollection() const;
 
