@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -36,7 +36,7 @@ void GenericPluginInterface::setActionTypes(const QVector<ActionType> &type)
 
 void GenericPluginInterface::addActionType(ActionType type)
 {
-    //TODO check already existence ?
+    // TODO check already existence ?
     d->actionTypes.append(type);
 }
 
@@ -47,31 +47,31 @@ QVector<ActionType> GenericPluginInterface::actionTypes() const
 
 void GenericPluginInterface::updateActions(int numberOfSelectedItems, int numberOfSelectedCollections)
 {
-    Q_UNUSED(numberOfSelectedItems);
-    Q_UNUSED(numberOfSelectedCollections);
+    Q_UNUSED(numberOfSelectedItems)
+    Q_UNUSED(numberOfSelectedCollections)
 }
 
 void GenericPluginInterface::setCurrentItems(const Akonadi::Item::List &items)
 {
-    Q_UNUSED(items);
+    Q_UNUSED(items)
 }
 
 void GenericPluginInterface::setItems(const Akonadi::Item::List &items)
 {
-    Q_UNUSED(items);
+    Q_UNUSED(items)
 }
 
 void GenericPluginInterface::setCurrentCollection(const Akonadi::Collection &col)
 {
-    Q_UNUSED(col);
+    Q_UNUSED(col)
 }
 
 void GenericPluginInterface::setCollections(const Akonadi::Collection::List &cols)
 {
-    Q_UNUSED(cols);
+    Q_UNUSED(cols)
 }
 
-PimCommon::GenericPluginInterface::RequireTypes GenericPluginInterface::requires() const
+PimCommon::GenericPluginInterface::RequireTypes GenericPluginInterface::requiresFeatures() const
 {
     return None;
 }
